"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Record = exports.SqliteDB = void 0;
const utils_1 = __importDefault(require("./utils"));
const dayjs_1 = __importDefault(require("dayjs"));
const sqlite3_1 = __importDefault(require("sqlite3"));
console.inspectEnable = true;
class SqliteDB extends sqlite3_1.default {
    beginTrans() {
        const code = this.begin();
        if (code !== sqlite3_1.default.OK && code !== sqlite3_1.default.DONE) {
            throw new Error(sqlite3_1.default.error(code));
        }
    }
    commitTrans() {
        const code = this.commit();
        if (code !== sqlite3_1.default.OK && code !== sqlite3_1.default.DONE) {
            throw new Error(sqlite3_1.default.error(code));
        }
    }
    rollbackTrans() {
        const code = this.rollback();
        if (code !== sqlite3_1.default.OK && code !== sqlite3_1.default.DONE) {
            console.error(sqlite3_1.default.error(code));
            return false;
        }
        else {
            return true;
        }
    }
    runSql(sql, ...params) {
        const code = this.run(sql, ...params);
        if (code !== sqlite3_1.default.OK) {
            throw new Error(sqlite3_1.default.error(code));
        }
        console.info(sql.trim().split(' ')[0]);
    }
    runSelectSql(sql, ...params) {
        const list = [];
        const code = this.run(sql, ...params, (row) => {
            list.push(row);
        });
        if (code !== sqlite3_1.default.OK) {
            throw new Error(sqlite3_1.default.error(code));
        }
        return list;
    }
}
exports.SqliteDB = SqliteDB;
class Record {
    constructor(path, tables) {
        this.tables = { logName: 'log', alarmName: 'alarm' };
        if (tables) {
            tables.logName = tables.logName || 'log';
            tables.alarmName = tables.alarmName || 'alarm';
        }
        this.sqlDB = new SqliteDB(path, 'c+');
        this.createLogTable();
        this.createAlarmTable();
    }
    addLog(params) {
        try {
            const data = Object.assign(Object.assign(Object.assign({ uuid: utils_1.default.uuid32() }, Record.DEFAULT_LOG), params), { create_time: utils_1.default.datetime() });
            const sql = `INSERT INTO ${this.tables.logName} VALUES(
        '${data.uuid}',
        '${data.category}',
        '${data.type}',
        '${data.status}',
        '${data.msg}',
        '${data.username}',
        '${data.station_uuid}',
        '${data.create_time}'
      )`;
            this.sqlDB.runSql(sql);
            return { code: 1, message: '操作成功！' };
        }
        catch (error) {
            console.error('addLog: ', error);
            return { code: 0, message: '操作失败！' };
        }
    }
    clearLog(dateList) {
        try {
            if (!dateList) {
                const sql = `DELETE FROM ${this.tables.logName}`;
                this.sqlDB.runSql(sql);
            }
            else {
                dateList.forEach((item) => {
                    const date = dayjs_1.default(item).format('YYYY-MM-DD');
                    this.sqlDB.runSql(`DELETE FROM ${this.tables.logName} WHERE create_time BETWEEN '${date + ' 00:00:00'}' AND '${date + ' 23:59:59'}'`);
                });
            }
            return { code: 1, message: '操作成功！' };
        }
        catch (error) {
            console.error('clearLog: ', error);
            return { code: 0, message: '操作出现异常！' };
        }
    }
    getLogList(page = 0, params) {
        const offset = Record.PAGE_SIZE * page;
        let whereStr = '';
        if (params) {
            if (params.category) {
                whereStr += `category='${params.category}'`;
            }
            if (typeof params.type === 'number') {
                whereStr += `${whereStr ? ' AND ' : ''}type=${params.type}`;
            }
        }
        const sql = `SELECT uuid,category,type,status,msg,create_time FROM ${this.tables.logName} ${whereStr ? 'WHERE ' + whereStr : ''} LIMIT ${Record.PAGE_SIZE} OFFSET ${offset}`;
        try {
            const list = this.sqlDB.runSelectSql(sql);
            return list;
        }
        catch (error) {
            console.error('getLogList: ', error);
        }
    }
    addAlarm(params) {
        try {
            const data = Object.assign(Object.assign(Object.assign({ uuid: utils_1.default.uuid32() }, Record.DEFAULT_ALARM), params), { create_time: utils_1.default.datetime() });
            const sql = `INSERT INTO ${this.tables.alarmName} VALUES(
        '${data.uuid}',
        '${data.level}',
        '${data.msg}',
        '${data.status}',
        '${data.create_time}',
        '${data.handle_name}',
        '${data.handle_time}'
      )`;
            this.sqlDB.runSql(sql);
            return { code: 1, message: '操作成功！' };
        }
        catch (error) {
            console.error('addALarm: ', error);
            return { code: 0, message: '操作异常！' };
        }
    }
    updateAlarm(params) {
        const sql = `
      UPDATE ${this.tables.alarmName} 
      SET handle_name='${params.handle_name}',
          handle_time='${params.handle_time}',
          status=1
      WHERE uuid IN (${params.uuids.join(',')})
    `;
        try {
            this.sqlDB.runSql(sql);
            return { code: 1, message: '操作成功！' };
        }
        catch (error) {
            console.error('updateAlarm: ', error);
            return { code: 0, message: '操作异常！' };
        }
    }
    clearAlarm(dateList) {
        try {
            if (!dateList) {
                const sql = `DELETE FROM ${this.tables.alarmName}`;
                this.sqlDB.runSql(sql);
            }
            else {
                dateList.forEach((item) => {
                    const date = dayjs_1.default(item).format('YYYY-MM-DD');
                    this.sqlDB.runSql(`DELETE FROM ${this.tables.alarmName} WHERE create_time BETWEEN '${date + ' 00:00:00'}' AND '${date + ' 23:59:59'}'`);
                });
            }
            return { code: 1, message: '操作成功！' };
        }
        catch (error) {
            console.error('clearAlarm: ', error);
            return { code: 0, message: '操作出现异常！' };
        }
    }
    getAlarmList(page = 0, params) {
        const offset = Record.PAGE_SIZE * page;
        let whereStr = '';
        if (params) {
            if (typeof params.level === 'number') {
                whereStr += `level=${params.level}`;
            }
            if (typeof params.status === 'number') {
                whereStr += `${whereStr ? ' AND ' : ''}type=${params.status}`;
            }
        }
        const sql = `SELECT uuid,level,msg,status,create_time,handle_name,handle_time FROM ${this.tables.logName} ${whereStr ? 'WHERE ' + whereStr : ''} LIMIT ${Record.PAGE_SIZE} OFFSET ${offset}`;
        try {
            const list = this.sqlDB.runSelectSql(sql);
            return list;
        }
        catch (error) {
            console.error('getAlarmList: ', error);
        }
    }
    createLogTable() {
        try {
            this.sqlDB.beginTrans();
            this.sqlDB.runSql(`
        CREATE TABLE IF NOT EXISTS ${this.tables.logName} (
            uuid CHAR(32) PRIMARY KEY NOT NULL,
            category text NOT NULL,
            type INTEGER NOT NULL,
            status TEXT NOT NULL,
            msg TEXT NOT NULL,
            username TEXT NOT NULL,
            station_uuid CHAR(32) NOT NULL,
            create_time DATETIME NOT NULL
        )
    `);
            this.sqlDB.commitTrans();
            console.info(`Datasheet ${this.tables.logName} initialization succeeded!`);
        }
        catch (error) {
            this.sqlDB.rollbackTrans();
            console.error('[createTable]: ', error);
        }
    }
    createAlarmTable() {
        try {
            this.sqlDB.beginTrans();
            this.sqlDB.runSql(`
        CREATE TABLE IF NOT EXISTS ${this.tables.alarmName} (
            uuid CHAR(32) PRIMARY KEY NOT NULL,
            level INTEGER NOT NULL,
            msg TEXT NOT NULL,
            station_id CHAR(32) NOT NULL,
            create_time DATETIME NOT NULL
        )
    `);
            this.sqlDB.commitTrans();
            console.info(`Datasheet ${this.tables.alarmName} initialization succeeded!`);
        }
        catch (error) {
            this.sqlDB.rollbackTrans();
            console.error('[createTable]: ', error);
        }
    }
}
exports.Record = Record;
Record.PAGE_SIZE = 10;
Record.DEFAULT_LOG = {
    category: 'default',
    type: 0,
    status: 'info',
    msg: '',
    username: '',
    station_uuid: ''
};
Record.DEFAULT_ALARM = {
    level: 3,
    msg: '',
    status: 0,
    handle_name: '',
    handle_time: ''
};
